unit Unit1;

interface

uses
  Winapi.Windows, Winapi.Messages, System.SysUtils, System.Variants, System.Classes, Vcl.Graphics,
  Vcl.Controls, Vcl.Forms, Vcl.Dialogs, VclTee.TeeGDIPlus, Vcl.StdCtrls,
  VCLTee.TeEngine, VCLTee.TeeProcs, VCLTee.Chart, Vcl.ExtCtrls, VCLTee.Series;

type
  TForm1 = class(TForm)
    Panel1: TPanel;
    Chart1: TChart;
    rbtnLines: TRadioButton;
    rbtnBars: TRadioButton;
    Series1: TLineSeries;
    procedure Chart1MouseMove(Sender: TObject; Shift: TShiftState; X, Y: Integer);
    procedure rbtnBarsClick(Sender: TObject);
  private
    { Private declarations }
    FAntClickedIndex: integer;
    FSavedColor: TColor;
    procedure ClearHighlightedSeries(aChart: TChart);
    procedure UpdateChart;
  public
    { Public declarations }
    constructor Create(aOwner: TComponent); override;
  end;

var
  Form1: TForm1;

implementation

uses
  math;

{$R *.dfm}

const
  HIGHLIGHT_COLOR = clWebOrange;


procedure TForm1.ClearHighlightedSeries(aChart: TChart);
var
  lSeries: TChartSeries;
  I: integer;
  lLineSeries: TLineSeries;
begin
  for I := 0 to aChart.SeriesCount - 1 do
  begin
    lSeries := aChart.Series[I];
    if (lSeries is TLineSeries) then
    begin
      lLineSeries := TLineSeries(lSeries);
      if lLineSeries.Color = HIGHLIGHT_COLOR then
        lLineSeries.Color := FSavedColor;
      lLineSeries.Pen.Width := 1;
    end;

  end;
  FAntClickedIndex := -1;
end;

constructor TForm1.Create(aOwner: TComponent);
begin
  inherited;
  FAntClickedIndex := -1;
  UpdateChart;
end;

procedure TForm1.Chart1MouseMove(Sender: TObject; Shift: TShiftState; X, Y:
    Integer);
var
  lClickedIdx: Integer;
  lSeries: TChartSeries;
  lChart: TChart;
begin
  Assert(Sender is TChart);
  lChart := TChart(Sender);
  lClickedIdx:= lChart.Legend.Clicked(X,Y);

  if (lClickedIdx > -1) then
  begin
    if (FAntClickedIndex <> lClickedIdx) then
    begin
      ClearHighlightedSeries(lChart);

      // ****************************************
      //
      //   When this is a bar series, this code
      //   does not work correctly
      //
      // ****************************************

      if InRange(lClickedIdx, 0, lChart.SeriesCount-1) then
      begin
        lSeries := lChart[lClickedIdx];
        if assigned(lSeries) then
        begin
          FSavedColor := lSeries.Color;
          lSeries.Color := HIGHLIGHT_COLOR;
          if (lSeries is TLineSeries) then
            TLineSeries(lSeries).Pen.Width := 2;
        end;

        FAntClickedIndex := lClickedIdx;
      end;
    end;
  end
  else
  if (FAntClickedIndex > -1) then
    ClearHighlightedSeries(lChart);
end;

procedure TForm1.rbtnBarsClick(Sender: TObject);
begin
  UpdateChart;
end;

procedure TForm1.UpdateChart;
var
  I: Integer;
  lLineSeries: TLineSeries;
  lBarSeries: TBarSeries;
begin
  Chart1.FreeAllSeries;
  if rbtnBars.Checked then
  begin
    lBarSeries := TBarSeries.Create(self);
    lBarSeries.ParentChart := Chart1;
    lBarSeries.Marks.Visible := false; // hides tool tips
    lBarSeries.Pen.Visible := false; // hides border around bar

    for I := 1 to 6 do
      lBarSeries.AddBar(Random(100), 'Series #' + IntToStr(I), clTeeColor);
  end
  else
  begin
    for I := 1 to 5 do
    begin
      lLineSeries := TLineSeries.Create(self);
      lLineSeries.ParentChart := Chart1;
      lLineSeries.Title := 'Series #' + IntToStr(I);
      lLineSeries.FillSampleValues(10);
    end;
  end;
end;

end.
